<template>
	<div class="model-binding-right-box">
		<div id="mainChart" style="height: calc(100% - 25px)"></div>
	</div>
</template>
<script setup lang="ts">
import * as echarts from 'echarts';
import { onMounted, watch, reactive, shallowRef, toRefs } from 'vue';
import { formatTime } from '/@/utils/istation/common.js';
const myChart = shallowRef(null);
// 定义变量内容
const state = reactive({
	themeTime: '' as any,
	queryDisabled: false,
	chartDataInfo: {
		SeriesData: [],
		XData: [],
	},
	getFreshData: [], //x轴y轴的数据
	selectSignalID: '',
	selectSignalName: '',
	echartTitle: '',
});

onMounted(() => {
	window.addEventListener('resize', selfAdaption);
});
//#region ====================== 图表传参 ======================
const props = defineProps({
	selectDataInfo: {
		type: Object,
	},
	echartBar: {
		type: Object,
	},
});
let { selectDataInfo, echartBar } = toRefs(props);
watch(selectDataInfo, async (newVal, oldVal) => {
	if (newVal == oldVal) {
		return;
	}
	state.selectSignalID = newVal.SignalID;
	// console.log(state.selectSignalID, 44);
	state.echartTitle = newVal.selectIDTitle;
});
watch(echartBar, async (newVal, oldVal) => {
	if (newVal == oldVal) {
		return;
	}
	state.chartDataInfo.SeriesData = newVal.SeriesData;
	state.chartDataInfo.XData = newVal.XData;
	setTimeout(() => {
		drawBar();
	}, 100);
});
//#endregion

//#region ====================== 绘图init ======================
//  初始化echarts折线图
const drawBar = () => {
	myChart.value && myChart.value.clear();
	//先获取Dom上的实例
	let chartDom = echarts.getInstanceByDom(document.getElementById('mainChart') as HTMLDivElement);
	//然后判断实例是否存在，如果不存在，就创建新实例
	if (chartDom == null) {
		chartDom = echarts.init(document.getElementById('mainChart') as HTMLDivElement);
		myChart.value = chartDom;
	}

	let series_arr: any = [];
	series_arr.push({
		type: 'bar',
		barWidth: '30px',
		showBackground: true,
		backgroundStyle: {
			color: 'rgba(180, 180, 180, 0.2)',
		},

		data: state.chartDataInfo.SeriesData,
	});

	let option = {
		tooltip: {
			trigger: 'axis',
			axisPointer: {
				type: 'shadow',
			},
		},
		grid: {
			left: '3%',
			right: '4%',
			bottom: '3%',
			containLabel: true,
		},
		xAxis: [
			{
				name: '时间',
				type: 'category',
				data: state.chartDataInfo.XData,
				axisTick: {
					alignWithLabel: true,
				},
				axisLabel: {
					formatter: function (value) {
						const date = new Date(value);
						return formatTime('yyyy-MM-dd', date);
					},
				},
			},
		],
		yAxis: [
			{
				name: '值',
				type: 'value',
				// 整条y轴
				axisLine: {
					show: true,
				},
			},
		],
		series: series_arr,
	};
	myChart.value.setOption(option);
	myChart.value.resize();
};
//#endregion
//#region ====================== 图表自适应 ======================

//  自适应
const selfAdaption = () => {
	if (!myChart.value) return;
	myChart.value.resize();
	setTimeout(() => {
		drawBar();
	}, 100);
};
//#endregion
</script>
<style scoped lang="scss">
.model-binding-right-box {
	width: 100%;
	height: 100%;
	background: #fff;
}
</style>
